<?php
/**
 * Theme menu page.
 *
 * @package Galaxis
 */

/**
 * Adds a theme menu page.
 */
function galaxis_create_menu() {
	$galaxis_page = add_theme_page( 'Galaxis', 'Galaxis', 'edit_theme_options', 'galaxis-options', 'galaxis_page' );
	add_action( 'admin_print_styles-' . $galaxis_page, 'galaxis_options_styles' );
}
add_action( 'admin_menu', 'galaxis_create_menu' );

if ( ! function_exists( 'galaxis_page' ) ) {
	/**
	 * Builds the content of the theme page.
	 */
	function galaxis_page() {
		?>
		<div class="wrap">
			<div class="metabox-holder">
				<div class="galaxis-panel">
					<div class="galaxis-container">
						<div class="galaxis-title">
							Galaxis
						</div>
					</div>
				</div>

				<div class="galaxis-container">
					<div class="galaxis-panel">
						<div class="galaxis-panel-content">
							<span class="galaxis-panel-title"><?php esc_html_e( 'Customize Theme', 'galaxis' ); ?></span>
							<p class="description">
								<?php esc_html_e( 'You can customize the theme using the theme options available in the customizer.', 'galaxis' ); ?>
							</p>
						</div>
						<div class="galaxis-panel-actions">
							<a target="_blank" href="<?php echo esc_url( admin_url( 'customize.php' ) ); ?>" class="button"><?php esc_html_e( 'Theme Options', 'galaxis' ); ?></a>
						</div>
					</div>
					<div class="galaxis-panel">
						<div class="galaxis-panel-content">
							<span class="galaxis-panel-title"><?php esc_html_e( 'Menus', 'galaxis' ); ?></span>
							<p class="description">
								<?php esc_html_e( 'You can create a menu and assign it to a menu location. Galaxis comes with three menu locations which include primary menu, footer menu, and social links menu.', 'galaxis' ); ?>
							</p>
						</div>
						<div class="galaxis-panel-actions">
							<a target="_blank" href="<?php echo esc_url( admin_url( 'nav-menus.php' ) ); ?>" class="button"><?php esc_html_e( 'Menus', 'galaxis' ); ?></a>
						</div>
					</div>
					<div class="galaxis-panel">
						<div class="galaxis-panel-content">
							<span class="galaxis-panel-title"><?php esc_html_e( 'Theme Widgets', 'galaxis' ); ?></span>
							<p class="description">
								<?php esc_html_e( 'You can drag and drop widgets to the widget area. Galaxis comes with a main sidebar widget area.', 'galaxis' ); ?>
							</p>
						</div>
						<div class="galaxis-panel-actions">
							<a target="_blank" href="<?php echo esc_url( admin_url( 'widgets.php' ) ); ?>" class="button"><?php esc_html_e( 'Widgets', 'galaxis' ); ?></a>
						</div>
					</div>
					<div class="galaxis-panel">
						<div class="galaxis-panel-content">
							<span class="galaxis-panel-title"><?php esc_html_e( 'Frequently Asked Questions', 'galaxis' ); ?></span>
							<p class="description">
								<?php esc_html_e( 'You can check the frequently asked questions related to the theme configuration.', 'galaxis' ); ?>
							</p>
						</div>
						<div class="galaxis-panel-actions">
							<a target="_blank" href="https://scriptstown.com/wordpress-themes/galaxis-wordpress-theme/#description" class="button"><?php esc_html_e( 'Click Here', 'galaxis' ); ?></a>
						</div>
					</div>
					<div class="galaxis-panel">
						<div class="galaxis-panel-content">
							<span class="galaxis-panel-title"><?php esc_html_e( 'Premium Version', 'galaxis' ); ?></span>
							<p class="description">
								<?php esc_html_e( 'Premium version of this theme comes with extra features like front page sections, custom sections, services section, call to action buttons, parallax backgrounds, footer widget area, and much more. You can check the detail and the demo.', 'galaxis' ); ?>
							</p>
						</div>
						<div class="galaxis-panel-actions">
							<a target="_blank" href="https://scriptstown.com/account/signup/galaxis-premium-wordpress-theme" class="button"><?php esc_html_e( 'Get Premium', 'galaxis' ); ?></a>
							<a target="_blank" href="https://scriptstown.com/demo/galaxis-premium-wordpress-theme/" class="button button-primary"><strong><?php esc_html_e( 'View Demo', 'galaxis' ); ?></strong></a>
						</div>
					</div>
					<div class="galaxis-panel">
						<div class="galaxis-panel-content">
							<?php esc_html_e( 'If you like this theme, then you can leave a review. This will encourage us to improve the theme and add more features to the theme.', 'galaxis' ); ?>
							<br>
							<a target="_blank" href="https://wordpress.org/support/theme/galaxis/reviews/#new-post" class="galaxis-review-stars-link">
								<div class="vers column-rating">
									<div class="star-rating">
										<span class="screen-reader-text"><?php esc_html_e( 'If you like this theme, then you can leave a review.', 'galaxis' ); ?></span>
										<div class="star star-full" aria-hidden="true"></div>
										<div class="star star-full" aria-hidden="true"></div>
										<div class="star star-full" aria-hidden="true"></div>
										<div class="star star-full" aria-hidden="true"></div>
										<div class="star star-full" aria-hidden="true"></div>
									</div>
								</div>
							</a>
						</div>
						<div class="galaxis-panel-actions">
							<a target="_blank" href="https://wordpress.org/support/theme/galaxis/reviews/#new-post" class="button"><?php esc_html_e( 'Leave a Review', 'galaxis' ); ?></a>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'galaxis_options_styles' ) ) {
	/**
	 * Enqueue styles for the theme page.
	 */
	function galaxis_options_styles() {
		wp_enqueue_style( 'galaxis-options', get_template_directory_uri() . '/inc/admin.css', array(), GALAXIS_VERSION );
	}
}
